@@ -36,6 +36,9 @@ class PageAdmin(admin.ModelAdmin):
     #if getattr(settings, 'PAGE_USE_SITE_ID'):
     general_fields.append('sites')
     insert_point = general_fields.index('status') + 1
+    # Strange django behavior. If not provided, django will try to find
+    # 'page' foreign key in all registered models
+    inlines = []
 
     if settings.PAGE_TAGGING:
         general_fields.insert(insert_point, 'tags')
@@ -76,11 +79,6 @@ class PageAdmin(admin.ModelAdmin):
             'javascript/pages_form.js',
         )]
 
-    def __init__(self, *args, **kwds):
-        for model, options in get_connected():
-            self.inlines.append(make_inline_admin(model, options))
-        return super(PageAdmin, self).__init__(*args, **kwds)
-
     def __call__(self, request, url):
         """
         Delegate to the appropriate method, based on the URL.
@@ -265,7 +263,7 @@ class PageAdmin(admin.ModelAdmin):
         the request."""
         form = super(PageAdmin, self).get_form(request, obj, **kwargs)
 
-        language = get_language_from_request(request, obj)
+        language = get_language_from_request(request)
         form.base_fields['language'].initial = language
         if obj:
             initial_slug = obj.slug(language=language, fallback=False)
@@ -304,8 +302,10 @@ class PageAdmin(admin.ModelAdmin):
 
     def change_view(self, request, object_id, extra_context=None):
         """The 'change' admin view for the Page model."""
+        lang = get_language_from_request(request)
         extra_context = {
-            'language': get_language_from_request(request),
+            'language': lang,
+            'lang': lang,
             'page_languages': settings.PAGE_LANGUAGES,
         }
         try:
@@ -361,6 +361,8 @@ class PageAdmin(admin.ModelAdmin):
 
     def list_pages(self, request, template_name=None, extra_context=None):
         """List root pages"""
+        if not admin.site.has_permission(request):
+            return admin.site.login(request)
         # HACK: overrides the changelist template and later resets it to None
         if template_name:
             self.change_list_template = template_name
@@ -399,6 +401,9 @@ class PageAdmin(admin.ModelAdmin):
                     template_name='admin/pages/page/change_list_table.html')
         return HttpResponseRedirect('../../')
 
+for model, options in get_connected():
+    PageAdmin.inlines.append(make_inline_admin(model, options))
+
 try:
     admin.site.register(Page, PageAdmin)
 except AlreadyRegistered:
