@@ -8,8 +8,8 @@ from django.conf import settings as global_settings
 import urllib
 
 from pages import settings
-from pages.models import Content, Page, PageAlias
-from pages.http import get_language_from_request
+from pages.models import Content, Page
+from pages.views import details
 
 register = template.Library()
 
@@ -21,7 +21,7 @@ def get_content(context, page, content_type, lang, fallback=True):
         return ''
 
     if not lang and 'lang' in context:
-        lang = context['lang']
+        lang = context.get('lang', settings.PAGE_DEFAULT_LANGUAGE)
     
     # if the page is a SafeUnicode, try to use it like a slug
     if isinstance(page, SafeUnicode) or isinstance(page, unicode):
@@ -29,11 +29,6 @@ def get_content(context, page, content_type, lang, fallback=True):
 
     if not page:
         return ''
-    
-    # now that we are sure to have a page object, we can found the content's
-    # language more accuratly
-    """if not absolute_lang:
-        absolute_lang = get_language_from_request(context['lang'], page)"""
 
     c = Content.objects.get_content(page, lang, content_type, fallback)
     return c
@@ -56,8 +51,8 @@ register.filter(has_permission)
 def pages_menu(context, page, url='/'):
     """Render a nested list of all children of the given page, including
     this page"""
-    lang = context['lang']
-    path = context['path']
+    lang = context.get('lang', settings.PAGE_DEFAULT_LANGUAGE)
+    path = context.get('path', None)
     site_id = None
     children = page.get_children_for_frontend()
     if 'current_page' in context:
@@ -69,8 +64,8 @@ pages_menu = register.inclusion_tag('pages/menu.html',
 def pages_sub_menu(context, page, url='/'):
     """Get the root page of the given page and
     render a nested list of all root's children pages"""
-    lang = context['lang']
-    path = context['path']
+    lang = context.get('lang', settings.PAGE_DEFAULT_LANGUAGE)
+    path = context.get('path', None)
     root = page.get_root()
     children = root.get_children_for_frontend()
     if 'current_page' in context:
@@ -94,7 +89,7 @@ def pages_admin_menu(context, page, url='', level=None):
     page_languages = settings.PAGE_LANGUAGES
     has_permission = page.has_page_permission(request)
     PAGES_MEDIA_URL = settings.PAGES_MEDIA_URL
-    lang = context.get('lang', None)
+    lang = context.get('lang', settings.PAGE_DEFAULT_LANGUAGE)
 
     return locals()
 pages_admin_menu = register.inclusion_tag('admin/pages/page/menu.html',
@@ -134,7 +129,7 @@ def show_absolute_url(context, page, lang=None):
     page -- the page object or a slug string
     lang -- the wanted language (defaults to None, uses request object else)
     """
-    lang = context.get('lang', None)
+    lang = context.get('lang', settings.PAGE_DEFAULT_LANGUAGE)
     # if the page is a SafeUnicode, try to use it like a slug
     if isinstance(page, SafeUnicode) or isinstance(page, unicode):
         page = Page.objects.from_path(page, lang)
@@ -213,19 +208,20 @@ do_get_content = register.tag('get_content', do_get_content)
 
 
 class LoadPagesNode(template.Node):
-    """Load page+ node"""
+    """Load page node."""
     def render(self, context):
-        if (not context.has_key('pages')):
-            context['pages'] = Page.objects.navigation()
         request = context['request']
-        if (not context.has_key('current_page')):
-            alias = PageAlias.objects.get_for_url(request, request.path)
-            if alias:
-                context['current_page'] = alias.page
+        try:
+            page_dict = details(request, only_context=True)
+            context.update(page_dict)
+        except Exception, e:
+            context.update({'current_page': Page()})
+            pass
         return ''
 
 def do_load_pages(parser, token):
-    """Load the navigation pages into the current context
+    """Load the navigation pages, lang, and current_page variables into the
+    current context.
 
     eg:
     <ul>
@@ -242,7 +238,7 @@ do_load_pages = register.tag('load_pages', do_load_pages)
 
 class PlaceholderNode(template.Node):
     """This template node is used to output page content and
-    is also used in the admin to dynamically generate input fields.
+    also in the admin to dynamically generate input fields.
 
     Keyword arguments:
     name -- the name of the placeholder you want to show/create
@@ -297,7 +293,7 @@ class PlaceholderNode(template.Node):
         if not self.page in context:
             return ''
 
-        lang = context.get('lang', None)
+        lang = context.get('lang', settings.PAGE_DEFAULT_LANGUAGE)
         content = Content.objects.get_content(context[self.page], lang,
                                               self.name, True)
         if not content:
@@ -363,18 +359,21 @@ def pages_dynamic_tree_menu(context, page, url='/'):
     if 'current_page' in context:
         current_page = context['current_page']
         # if this node is expanded, we also have to render its children
-        # a node is expanded if it is the current node or one of its ancestors        
+        # a node is expanded if it is the current node or one of its ancestors
         if page.lft <= current_page.lft and page.rght >= current_page.rght:
             children = page.get_children_for_frontend() 
     return locals()
-
-pages_dynamic_tree_menu = register.inclusion_tag('pages/dynamic_tree_menu.html',
-                                                 takes_context=True)(pages_dynamic_tree_menu)
+pages_dynamic_tree_menu = register.inclusion_tag(
+    'pages/dynamic_tree_menu.html',
+    takes_context=True
+)(pages_dynamic_tree_menu)
 
 def pages_breadcrumb(context, page, url='/'):
     request = context['request']
     site_id = None
     pages = page.get_ancestors()
     return locals()
-pages_breadcrumb = register.inclusion_tag('pages/breadcrumb.html',
-                                                 takes_context=True)(pages_breadcrumb)
\ No newline at end of file
+pages_breadcrumb = register.inclusion_tag(
+    'pages/breadcrumb.html',
+    takes_context=True
+)(pages_breadcrumb)
